dd_functions: Differentiably definable (DD-finite) functions
============================================================

Description
-----------

Package to work with differentiably definable functions.

These generalize the class of differentially finite or "D-finite" functions:

- D-finite functions satisfy linear differential equations
  with polynomial coefficients
- DD-finite functions satisfy linear differential equations
  with D-finite functions as coefficients
- differentiably definable functions are obtained by iterating this

License
-------

GPLv3

Upstream Contact
----------------

- https://github.com/Antonio-JP/dd_functions
- https://github.com/passagemath/passagemath-pkg-dd_functions
